For details, see $\mbox{Kom\'{a}rek}$ (2006) and $\mbox{Kom\'{a}rek}$ and Lesaffre (2006b). We explain first in more detail a model without doubly censoring. Let $T_{i,l},\; i=1,\dots, N,\; l=1, 2$ be event times for $i$th cluster and the first and the second unit. The following regression model is assumed: $$\log(T_{i,l}) = \beta'x_{i,l} + \varepsilon_{i,l},\quad i=1,\dots,N,\;l=1,2$$ where $\beta$ is unknown regression parameter vector and $x_{i,l}$ is a vector of covariates. The bivariate error terms $\varepsilon_i=(\varepsilon_{i,1},\,\varepsilon_{i,2})',\;i=1,\dots,N$ are assumed to be i.i.d. with a~bivariate density $g_{\varepsilon}(e_1,\,e_2)$. This density is expressed as a~mixture of Bayesian G-splines (normal densities with equidistant means and constant variance matrices). We distinguish two, theoretically equivalent, specifications.
[object Object],[object Object] Personally, I found Specification 2 performing better. In the paper $\mbox{Kom{\'a}rek}$ and Lesaffre (2006b) only Specification 2 is described.
The mixture weights $w_{j_1,j_2},\;j_1=-K_1,\dots, K_1,\;j_2=-K_2,\dots, K_2$ are not estimated directly. To avoid the constraints $0 < w_{j_1,j_2} < 1$ and $\sum_{j_1=-K_1}^{K_1}\sum_{j_2=-K_2}^{K_2}w_{j_1,j_2} = 1$ transformed weights $a_{j_1,j_2},\;j_1=-K_1,\dots, K_1,\;j_2=-K_2,\dots, K_2$ related to the original weights by the logistic transformation: $$a_{j_1,j_2} = \frac{\exp(w_{j_1,j_2})}{\sum_{m_1}\sum_{m_2}\exp(w_{m_1,m_2})}$$ are estimated instead.
A~Bayesian model is set up for all unknown parameters. For more details I refer to $\mbox{Kom\'{a}rek and Lesaffre (2006b)}$ and to $\mbox{Kom\'{a}rek}$ (2006).
If there are doubly-censored data the model of the same type as above can be specified for both the onset time and the time-to-event.
bayesBisurvreg(formula, formula2, data = parent.frame(),
na.action = na.fail, onlyX = FALSE,
nsimul = list(niter = 10, nthin = 1, nburn = 0, nwrite = 10),
prior, prior.beta, init = list(iter = 0),
mcmc.par = list(type.update.a = "slice", k.overrelax.a = 1,
k.overrelax.sigma = 1, k.overrelax.scale = 1),
prior2, prior.beta2, init2,
mcmc.par2 = list(type.update.a = "slice", k.overrelax.a = 1,
k.overrelax.sigma = 1, k.overrelax.scale = 1),
store = list(a = FALSE, a2 = FALSE, y = FALSE, y2 = FALSE,
r = FALSE, r2 = FALSE),
dir = getwd())formula concerning the sort order applies here.na.fail.TRUE no MCMC sampling is performed and only the
design matrix (matrices) are returned. This can be useful to set up
correctly priors for regression parameters in the presence of
factor covariates.formula. See prior argument of
bayesHiformula.
This should be a~list with the following components:
[formula. The list can have the following components:
[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[objeformula are to be updated. The list can have the following components (all
of them have their default values):
[object Object],[object Object],[object Object],[objecformula2. See prior argument of
bayesHformula2).
This should be a~list with the same structure as prior.beta.formula2. The list has the same
structure as init.formula2 are to be updated. The list has the same
structure as mcmc.par.bayesBisurvreg containing an information
concerning the initial values and prior choices.