These are just sub-parts of `bayesBisurvreg' function to make it more readable for the programmer.
bayesBisurvreg.checkStore(store)bayesBisurvreg.priorInit(dim, prior, init, design, mcmc.par,
prior2, init2, design2, mcmc.par2,
doubly)
bayesBisurvreg.priorBeta(prior.beta, init, design)
bayesBisurvreg.writeHeaders(dir, dim, nP, doubly, prior.init, store,
design, design2)
store of the
function bayesBisurvregprior of the
function bayesBisurvregprior2 of the
function bayesBisurvreginit of the
function bayesBisurvreginit2 of the
function bayesBisurvregmcmc.par of the
function bayesBisurvregmcmc.par2 of the
function bayesBisurvregbayessurvreg.design related to either the onset time
if doubly censored observations or to the event time. Remark:
design$Y containbayessurvreg.design related to time-to-event
if doubly censored observations. Remark:
design2$Y contains original times and NOT theprior.beta or
prior.beta2 of the function bayesBisurvregbayesBisurvreg.priorInitbayesBisurvreg.checkStore