These are just sub-parts of `bayessurvreg' functions to make them more readable for the programmer.
bayessurvreg.design(m, formula, random, data, transform, dtransform)
bayessurvreg.checknsimul(nsimul)ncluster = nncluster with
numbers of observations within each cluster. In the case of
bivariate observations this is a~vector filled with 2's, if there are
no random effects and if the observations are not bivariate then
this is a~vector filled with 1'sTRUE/FALSE indicating whether the
random intercept is included in the modelformula using model.extractformula using
model.matrix functionn with identifications of
clusters (as given by cluster in formula)nX identifying fixed and random
effects. indb[j] = -1 if the $j$th column of matrix
$X$ is a fixed effects. it is equal to $l$ if the
$j$th column of matrix $X$ corresponds to the
$l$th random effect (in C++ indexing)Xinit