These are just sub-parts of `bayessurvreg2' function to make it more readable for the programmer.
bayessurvreg2.checkStore(store)bayessurvreg2.priorInit(prior, init, design, mcmc.par,
prior2, init2, design2, mcmc.par2, doubly)
bayessurvreg2.priorBeta(prior.beta, init, design)
bayessurvreg2.priorb(prior.b, init, design)
bayessurvreg2.writeHeaders(dir, doubly, prior.init, store, design, design2)
store of the
function bayessurvreg2prior of the
function bayessurvreg2prior2 of the
function bayessurvreg2init of the
function bayessurvreg2init2 of the
function bayessurvreg2mcmc.par of the
function bayessurvreg2mcmc.par2 of the
function bayessurvreg2bayessurvreg.design related to either the onset time
if doubly censored observations or to the event time. Remark:
design$Y containbayessurvreg.design related to time-to-event
if doubly censored observations. Remark:
design2$Y contains original times and NOT theprior.beta or
prior.beta2 of the function bayessurvreg2prior.b or
prior.b2 of the function bayessurvreg2init or init2
of the function bayessurvreg2bayessurvreg2.priorInitbayesBisurvreg.priorInit.