This function serves to summarize the MCMC chains related to the distributional parts
of the considered models obtained using the functions:
bayesHistogram and bayesBisurvreg.
If asked, this function returns also the values of the marginal G-spline evaluated in a grid at each iteration of MCMC.
marginal.bayesGspline(dir = getwd(), extens = "", K, grid1, grid2,
skip = 0, by = 1, last.iter, nwrite, only.aver = TRUE)bayes*survreg* function was used, specify the argument
extensmixmoment.sim.nwriteth iteration count of
iterations change).TRUE/FALSE, if TRUE only MCMC average is
returned otherwise also values of the marginal G-spline at each iteration are
returned (which might ask for quite lots of memory).marginal.bayesGspline is returned. This object is a
list with components margin1 and margin2 (for two margins). Both margin1 and margin2 components are data.frames with
columns named grid and average where
grid.marginal.bayesGspline.$\mbox{Kom\'{a}rek}$, A. and Lesaffre, E. (2006b). Bayesian semi-parametric accelerated failurew time model for paired doubly interval-censored data. Statistical Modelling, 6, 3--22.
## See the description of R commands for
## the models described in
## Komarek (2006),
## Komarek and Lesaffre (2006b),
##
## R commands available
## in the documentation
## directory of this package
## as tandmobPA.pdf, tandmobPA.R.
##Run the code above in your browser using DataLab