Learn R Programming

bayesSurv (version 2.4)

print.bayesDensity: Print a summary for the density estimate based on the Bayesian model.

Description

This function prints a~object created by bayesDensity.

Usage

## S3 method for class 'bayesDensity':
print(x, \dots)

Arguments

x
an object of class bayesDensity.
...
this is here for a consistency with a generic function.