bayesHistogram or
bayesBisurvreg. For both these function their argument prior$specification must
be equal to 2!
When $G$ is a bivariate distribution function, the population version of the Kendall's tau is defined as $$\tau = 4\int G dG - 1$$.
For the model estimated using one of the above mentioned functions the value of Kendall's tau at each iteration of MCMC is equal to $$\tau = 4\sum_{i=-K_1}^{K_1}\sum_{j=-K_2}^{K_2}\sum_{k=-K_1}^{K_1}\sum_{l=-K_2}^{K_2}w_{i,j} w_{k,l} \Phi\left(\frac{\mu_{1,i} - \mu_{1,k}}{\sqrt{2}\sigma_1}\right) \Phi\left(\frac{\mu_{2,j} - \mu_{2,l}}{\sqrt{2}\sigma_2}\right) - 1,$$ where $\mu_{1,-K_1},\dots,\mu_{1,K_1}$ are knots in the first margin, $\mu_{2,-K_2},\dots,\mu_{2,K_2}$ are knots in the second margin, $\sigma_1$ is the basis standard deviation in the first margin, $\sigma_2$ is the basis standard deviation in the second margin, and $w_{i,j},\;i=-K_1,\dots,K_1,\;j=-K_2,\dots,K_2$ are the G-spline weights.
sampled.kendall.tau(dir = getwd(), extens = "", K,
skip = 0, by = 1, last.iter, nwrite)bayes*survreg* function was used, specify the argument
extens in thmixmoment.sim.nwriteth iteration count of
iterations change).$\mbox{Kom\'{a}rek}$, A. and Lesaffre, E. (2006b). Bayesian semi-parametric accelerated failurew time model for paired doubly interval-censored data. Statistical Modelling, 6, 3--22.
## See the description of R commands for
## the models described in
## Komarek (2006),
## Komarek and Lesaffre (2006b),
##
## R commands available
## in the documentation
## directory of this package
## tandmobPA.pdf, tandmobPA.R.
##Run the code above in your browser using DataLab