Learn R Programming

bayesSurv (version 0.3-2)

tandmobRoos: Signal Tandmobiel data, version Roos

Description

This is the dataset resulting from a longitudinal prospective dental study performed in Flanders (North of Belgium) in 1996 -- 2001. The cohort of 4,468 randomly sampled children who attended the first year of the basic school at the beginning of the study was annualy dental examined by one of 16 trained dentists. The original dataset consists thus of at most 6 dental observations for each child. The dataset presented here contains mainly the information on the emergence and caries times summarized in the interval-censored observations. Some baseline covariates are also included here.

For more detail on the design of the study see Vanobbergen et al. (2000).

This is the version of the dataset used first by Leroy et al. (2005) and contains a subset of the tandmob2. Some children were removed to satisfy inclusion criteria given in Leroy et al. (2005). Additionally, left-censored emergence times of the permanent first molars are adjusted according to the eruption stage (see Leroy et al., 2005). This data set was then used in the analyses presented in $\mbox{Kom\'{a}rek}$ and Lesaffre (2006, 2006b).

Usage

data(tandmobRoos)

Arguments

source

Biostatistical Centre, Katholieke Universiteit Leuven, Kapucijnenvoer 35, 3000 Leuven, Belgium

URL: http://med.kuleuven.be/biostat/

References

$\mbox{Kom\'{a}rek}$, A. and Lesaffre, E. (2006). Bayesian accelerated failure time model with multivariate doubly-interval-censored data and flexible distributional assumptions. Submitted. See Komarek_Lesaffre_2006.pdf.

$\mbox{Kom\'{a}rek}$, A. and Lesaffre, E. (2006b). Bayesian semiparametric accelerated failurew time model for paired doubly-interval-censored data. Submitted. See Komarek_Lesaffre_2006b.pdf.

Leroy, R., Bogaerts, K., Lesaffre, E., and Declerck, D. (2005). Effect of caries experience in primary molars on cavity formation in the adjacent permanent first molar. Caries Research, 39, 342--349. Vanobbergen, J., Martens, L., Lesaffre, E., and Declerck, D. (2000). The Signal-Tandmobiel project -- a longitudinal intervention health promotion study in Flanders (Belgium): baseline and first year results. European Journal of Paediatric Dentistry, 2, 87--96.