bayesDensity(dir = getwd(), stgrid, grid,
n.grid = 100, skip = 0, standard = TRUE, unstandard = TRUE)missing, the grid is
automatically computed.missing,
the grid is guessed from the first 20 sampled mixtures as the sequence starting with the minimal
sampled mixture mean minus 3 standard deviations ofgrid = NULL.TRUE then also standardized (zero mean,
unit variance) sampled densities are evaluated.TRUE then also original (unstandardized)
sampled densities are evaluated.bayesDensity is returned. This object is a
list and has potentially two components: standard and
unstandard. Each of these two components is a data.frame
with as many rows as number of grid points at which the density was
evaluated and with columns called `grid', `unconditional' and `k = 1',
..., `k = k.max' giving a predictive errr density, either averaged
over all sampled $k$s (unconditional) or averaged over a
psecific number of mixture components. Additionally, the object of class bayesDensity has three
attributes:
1 + kmax giving the
frequency of each $k$ in the sample.data.frame with columns called `intercept'
and `scale' giving the mean and variance of the sampled mixture at
each iteration of the McMC.data.frame with one column called `k' giving
number of mixture components at each iteration.bayesDensity.