This function serves to summarize the MCMC chains related to the distributional parts
of the considered models obtained using the functions:
bayesHistogram,
bayesBisurvreg, bayessurvreg2, bayessurvreg3.
If asked, this function returns also the values of the G-spline evaluated in a grid at each iteration of MCMC.
bayesGspline(dir = getwd(), extens="", extens.adjust="_b",
grid1, grid2, skip = 0, by = 1, last.iter, nwrite,
only.aver = TRUE, standard = FALSE, version = 0)bayessurvreg3, i.e. when both the distribution of the
error term and the random intercept was smissing if the G-spline is univariate.mixmoment.sim.nwriteth iteration count of
iterations change).TRUE/FALSE, if TRUE only MCMC average is
returned otherwise also values of the G-spline at each iteration are
returned (which might ask for quite lots of memory).TRUE/FALSE, if TRUE, each G-spline is
standardized to have zero mean and unit variance.bayes*survreg* function the
chains used by bayesGspline were created. Use the following:[object Object],[object Object],[object Object],[object Object]
bayesGspline is returned. This object is a
list with components
grid, value for the univariate G-spline and
components grid1, grid2, value for the bivariate G-spline.grid.length(grid1) times
length(grid2) with McMC averages of the G-spline evaluated in
bayesGspline. $\mbox{Kom\'{a}rek}$, A. and Lesaffre, E. (2006).
Bayesian accelerated failure time model with multivariate doubly-interval-censored data
and flexible distributional assumptions.
Submitted.
See Komarek_Lesaffre_2006.pdf.
$\mbox{Kom\'{a}rek}$, A. and Lesaffre, E. (2006b).
Bayesian semiparametric accelerated failurew time model for paired
doubly-interval-censored data.
Submitted.
See Komarek_Lesaffre_2006b.pdf.
$\mbox{Kom\'{a}rek}$, A. Lesaffre, E., and Legrand, C. (2006).
EORTC data article.
To be written.
## See the description of R commands for
## the models described in
## Komarek (2006),
## Komarek and Lesaffre (2006),
## Komarek and Lesaffre (2006b),
## Komarek, Lesaffre, and Legrand (2006).
##
## R commands available (or soon available)
## in the documentation
## directory of this package
## as tandmobCS.pdf, tandmobCS.R
## tandmobPA.pdf, tandmobPA.R.
##Run the code above in your browser using DataLab