This function serves to summarize the MCMC chains related to the distributional parts
of the considered models obtained using the functions:
bayesHistogram,
bayesBisurvreg, bayessurvreg2, bayessurvreg3.
If asked, this function returns also the values of the G-spline evaluated in a grid at each iteration of MCMC.
bayesGspline(dir = getwd(), extens="", extens.adjust="_b",
grid1, grid2, skip = 0, by = 1, last.iter, nwrite,
only.aver = TRUE, standard = FALSE, version = 0)bayessurvreg3, and when both the distribution of the
error term and the random intercept was spmissing if the G-spline is univariate.mixmoment.sim.nwriteth iteration count of
iterations change).TRUE/FALSE, if TRUE only MCMC average is
returned otherwise also values of the G-spline at each iteration are
returned (which might ask for quite lots of memory).TRUE/FALSE, if TRUE, each G-spline is
standardized to have zero mean and unit variance. Only applicable if
version = 30 or 31, otherwise standard is always set to FALSE.bayes*survreg* function the
chains used by bayesGspline were created. Use the following:[object Object],[object Object],[object Object],[object Object]
bayesGspline is returned. This object is a
list with components
grid, average for the univariate G-spline and
components grid1, grid2, average for the bivariate G-spline.grid.length(grid1) times
length(grid2) with McMC averages of the G-spline evaluated in
bayesGspline.Komárek, A. and Lesaffre, E. (2006). Bayesian semi-parametric accelerated failurew time model for paired doubly interval-censored data. Statistical Modelling, 6, 3--22. Komárek, A. and Lesaffre, E. (2008). Bayesian accelerated failure time model with multivariate doubly-interval-censored data and flexible distributional assumptions. Journal of the American Statistical Association, 103, 523--533.
Komárek, A., Lesaffre, E., and Legrand, C. (2007). Baseline and treatment effect heterogeneity for survival times between centers using a random effects accelerated failure time model with flexible error distribution. Statistics in Medicine, 26, 5457--5472.
## See the description of R commands for
## the models described in
## Komarek (2006),
## Komarek and Lesaffre (2006),
## Komarek and Lesaffre (2008),
## Komarek, Lesaffre, and Legrand (2007).
##
## R commands available
## in the documentation
## directory of this package
## - ex-tandmobPA.R and
## http://www.karlin.mff.cuni.cz/~komarek/software/bayesSurv/ex-tandmobPA.pdf
## - ex-tandmobCS.R and
## http://www.karlin.mff.cuni.cz/~komarek/software/bayesSurv/ex-tandmobCS.pdf
## - ex-eortc.R and
## http://www.karlin.mff.cuni.cz/~komarek/software/bayesSurv/ex-eortc.pdf
##Run the code above in your browser using DataLab