Usage
clean.Gspline(dir, label, care.of.y=TRUE)write.headers.Gspline(dir, dim, nP, label, gparmi,
store.a, store.y, store.r, care.of.y=TRUE)
Arguments
dir
a~string giving the path to the directory where to search or
store G-spline files
label
a~string with extension of the G-spline files
dim
dimension of the G-spline
nP
number of (bivariate) observations
gparmi
a~vector with integer arguments required by the
constructor of C++ class Gspline
store.a
logical, store transformed weights?
store.y
logical, store augmented observations?
store.r
logical, store allocations?
care.of.y
logical, do we wish to take care of the Y.sim file?