Learn R Programming

bayesSurv (version 2.4)

marginal.bayesGspline: Summary for the marginal density estimates based on the bivariate model with Bayesian G-splines.

Description

Compute the estimate of the marginal density function based on the values sampled using the MCMC (MCMC average evaluated in a grid of values) in a model where density is specified as a bivariate Bayesian G-spline.

This function serves to summarize the MCMC chains related to the distributional parts of the considered models obtained using the functions: bayesHistogram and bayesBisurvreg.

If asked, this function returns also the values of the marginal G-spline evaluated in a grid at each iteration of MCMC.

Usage

marginal.bayesGspline(dir = getwd(), extens = "", K, grid1, grid2,
   skip = 0, by = 1, last.iter, nwrite, only.aver = TRUE)

Arguments

dir
directory where to search for files (`mixmoment.sim', `mweight.sim', `mmean.sim', `gspline.sim') with the MCMC sample.
extens
an extension used to distinguish different sampled G-splines if more G-splines were used in one simulation (e.g. with doubly-censored data). According to which bayes*survreg* function was used, specify the argument extens
K
a~vector of length 2 specifying the number of knots at each side of the middle knot for each dimension of the G-spline.
grid1
grid of values from the first dimension at which the sampled marginal densities are to be evaluated.
grid2
grid of values from the second dimension at which the sampled marginal densities are to be evaluated.
skip
number of rows that should be skipped at the beginning of each *.sim file with the stored sample.
by
additional thinning of the sample.
last.iter
index of the last row from *.sim files that should be used. If not specified than it is set to the maximum available determined according to the file mixmoment.sim.
nwrite
frequency with which is the user informed about the progress of computation (every nwriteth iteration count of iterations change).
only.aver
TRUE/FALSE, if TRUE only MCMC average is returned otherwise also values of the marginal G-spline at each iteration are returned (which might ask for quite lots of memory).

Value

  • An object of class marginal.bayesGspline is returned. This object is a list with components margin1 and margin2 (for two margins).

    Both margin1 and margin2 components are data.frames with columns named grid and average where

  • gridis a grid of values (vector) at which the McMC average of the marginal G-spline was computed.
  • averageare McMC averages of the marginal G-spline (vector) evaluated in grid.
  • There exists a method to plot objects of the class marginal.bayesGspline.

References

Komárek, A. (2006). Accelerated Failure Time Models for Multivariate Interval-Censored Data with Flexible Distributional Assumptions. PhD. Thesis, Katholieke Universiteit Leuven, Faculteit Wetenschappen.

Komárek, A. and Lesaffre, E. (2006). Bayesian semi-parametric accelerated failurew time model for paired doubly interval-censored data. Statistical Modelling, 6, 3--22.

Examples

Run this code
## See the description of R commands for
## the models described in
## Komarek (2006),
## Komarek and Lesaffre (2006),
## 
## R commands available
## in the documentation
## directory of this package
## - see ex-tandmobPA.R and
##   http://www.karlin.mff.cuni.cz/~komarek/software/bayesSurv/ex-tandmobPA.pdf
##

Run the code above in your browser using DataLab