For more detail on the design of the study see Vanobbergen et al. (2000).
This is the version of the dataset used first by Leroy et al. (2005)
and contains a subset of the tandmob2. Some children
were removed to satisfy inclusion criteria given in Leroy et
al. (2005). Additionally, left-censored emergence times of the
permanent first molars are adjusted according to the eruption stage
(see Leroy et al., 2005).
This data set was then used in the analyses presented in
$\mbox{Kom\'{a}rek}$ and Lesaffre (2006, 2006b).
data(tandmobRoos) URL: http://med.kuleuven.be/biostat/
Komarek_Lesaffre_2006.pdf. $\mbox{Kom\'{a}rek}$, A. and Lesaffre, E. (2006b).
Bayesian semiparametric accelerated failurew time model for paired
doubly-interval-censored data.
Submitted.
See Komarek_Lesaffre_2006b.pdf.
Leroy, R., Bogaerts, K., Lesaffre, E., and Declerck, D. (2005). Effect of caries experience in primary molars on cavity formation in the adjacent permanent first molar. Caries Research, 39, 342--349. Vanobbergen, J., Martens, L., Lesaffre, E., and Declerck, D. (2000). The Signal-Tandmobiel project -- a longitudinal intervention health promotion study in Flanders (Belgium): baseline and first year results. European Journal of Paediatric Dentistry, 2, 87--96.